@@ -19,7 +19,7 @@ fn main() {
   };
 
   eprintln!("ref: {}", arguments.reference);
-  eprintln!("value: {}", value);
+  eprintln!("value: {value}");
 
-  println!("::set-output name=value::{}", value);
+  println!("::set-output name=value::{value}");
 }
