@@ -13,21 +13,25 @@ impl Compiler {
     let mut srcs: HashMap<PathBuf, &str> = HashMap::new();
     let mut loaded = Vec::new();
 
-    let mut stack: Vec<PathBuf> = Vec::new();
-    stack.push(root.into());
+    let mut stack: Vec<(PathBuf, u32)> = Vec::new();
+    stack.push((root.into(), 0));
 
-    while let Some(current) = stack.pop() {
+    while let Some((current, depth)) = stack.pop() {
       let (relative, src) = loader.load(root, &current)?;
       loaded.push(relative.into());
       let tokens = Lexer::lex(relative, src)?;
-      let mut ast = Parser::parse(&tokens)?;
+      let mut ast = Parser::parse(depth, &current, &tokens)?;
 
       paths.insert(current.clone(), relative.into());
       srcs.insert(current.clone(), src);
 
       for item in &mut ast.items {
         match item {
-          Item::Mod { name, absolute } => {
+          Item::Mod {
+            name,
+            absolute,
+            path,
+          } => {
             if !unstable {
               return Err(Error::Unstable {
                 message: "Modules are currently unstable.".into(),
@@ -36,21 +40,29 @@ impl Compiler {
 
             let parent = current.parent().unwrap();
 
-            let import = Self::find_module_file(parent, *name)?;
+            let import = if let Some(path) = path {
+              parent.join(Self::expand_tilde(&path.cooked)?)
+            } else {
+              Self::find_module_file(parent, *name)?
+            };
 
             if srcs.contains_key(&import) {
               return Err(Error::CircularImport { current, import });
             }
             *absolute = Some(import.clone());
-            stack.push(import);
+            stack.push((import, depth + 1));
           }
           Item::Import { relative, absolute } => {
-            let import = current.parent().unwrap().join(&relative.cooked).lexiclean();
+            let import = current
+              .parent()
+              .unwrap()
+              .join(Self::expand_tilde(&relative.cooked)?)
+              .lexiclean();
             if srcs.contains_key(&import) {
               return Err(Error::CircularImport { current, import });
             }
             *absolute = Some(import.clone());
-            stack.push(import);
+            stack.push((import, depth + 1));
           }
           _ => {}
         }
@@ -109,10 +121,20 @@ impl Compiler {
     }
   }
 
+  fn expand_tilde(path: &str) -> RunResult<'static, PathBuf> {
+    Ok(if let Some(path) = path.strip_prefix("~/") {
+      dirs::home_dir()
+        .ok_or(Error::Homedir)?
+        .join(path.trim_start_matches('/'))
+    } else {
+      PathBuf::from(path)
+    })
+  }
+
   #[cfg(test)]
   pub(crate) fn test_compile(src: &str) -> CompileResult<Justfile> {
     let tokens = Lexer::test_lex(src)?;
-    let ast = Parser::parse(&tokens)?;
+    let ast = Parser::parse(0, &PathBuf::new(), &tokens)?;
     let root = PathBuf::from("justfile");
     let mut asts: HashMap<PathBuf, Ast> = HashMap::new();
     asts.insert(root.clone(), ast);
