@@ -4,9 +4,13 @@
   clippy::let_underscore_untyped,
   clippy::needless_pass_by_value,
   clippy::similar_names,
+  clippy::struct_excessive_bools,
+  clippy::struct_field_names,
+  clippy::too_many_arguments,
   clippy::too_many_lines,
   clippy::unnecessary_wraps,
-  clippy::wildcard_imports
+  clippy::wildcard_imports,
+  overlapping_range_endpoints
 )]
 
 pub(crate) use {
