@@ -21,9 +21,10 @@ impl<'src> Node<'src> for Item<'src> {
       Item::Alias(alias) => alias.tree(),
       Item::Assignment(assignment) => assignment.tree(),
       Item::Comment(comment) => comment.tree(),
+      Item::Import { relative, .. } => Tree::atom("import").push(format!("{relative}")),
+      Item::Mod { name, .. } => Tree::atom("mod").push(name.lexeme()),
       Item::Recipe(recipe) => recipe.tree(),
       Item::Set(set) => set.tree(),
-      Item::Include { relative, .. } => Tree::atom("include").push(format!("\"{relative}\"")),
     }
   }
 }
